[Asterisk-code-review] spelling: cadence (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:04:37 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/16785 )


Change subject: spelling: cadence
......................................................................

spelling: cadence

Change-Id: Ie4740969444625e66f951c4622c842bbb95de2ec
---
M channels/chan_dahdi.c
1 file changed, 11 insertions(+), 11 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/85/16785/1

diff --git a/channels/chan_dahdi.c b/channels/chan_dahdi.c
index e750648..3454293 100644
--- a/channels/chan_dahdi.c
+++ b/channels/chan_dahdi.c
@@ -2897,13 +2897,13 @@
  *
  * \details
  * original dialstring:
- * DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadance#>|d][/extension[/options]]
+ * DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadence#>|d][/extension[/options]]
  *
  * The modified dialstring will have prefixed the channel-group section
  * with the ISDN channel restriction.
  *
  * buf:
- * DAHDI/i<span>-(g|G|r|R)<group#(0-63)>[c|r<cadance#>|d][/extension[/options]]
+ * DAHDI/i<span>-(g|G|r|R)<group#(0-63)>[c|r<cadence#>|d][/extension[/options]]
  *
  * The routine will check to see if the ISDN channel restriction is already
  * in the original dialstring.
@@ -13328,8 +13328,8 @@
 	int rr_starting_point;
 	/*! ISDN span where channels can be picked (Zero if not specified) */
 	int span;
-	/*! Analog channel distinctive ring cadance index. */
-	int cadance;
+	/*! Analog channel distinctive ring cadence index. */
+	int cadence;
 	/*! Dialing option. c/r/d if present and valid. */
 	char opt;
 	/*! TRUE if to search the channel list backwards. */
@@ -13355,10 +13355,10 @@
 	/*
 	 * data is ---v
 	 * Dial(DAHDI/pseudo[/extension[/options]])
-	 * Dial(DAHDI/<channel#>[c|r<cadance#>|d][/extension[/options]])
-	 * Dial(DAHDI/<subdir>!<channel#>[c|r<cadance#>|d][/extension[/options]])
+	 * Dial(DAHDI/<channel#>[c|r<cadence#>|d][/extension[/options]])
+	 * Dial(DAHDI/<subdir>!<channel#>[c|r<cadence#>|d][/extension[/options]])
 	 * Dial(DAHDI/i<span>[/extension[/options]])
-	 * Dial(DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadance#>|d][/extension[/options]])
+	 * Dial(DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadence#>|d][/extension[/options]])
 	 *
 	 * i - ISDN span channel restriction.
 	 *     Used by CC to ensure that the CC recall goes out the same span.
@@ -13371,7 +13371,7 @@
 	 * R - channel group allocation round robin search backward
 	 *
 	 * c - Wait for DTMF digit to confirm answer
 	 * r<cadance#> - Set distintive ring cadance number
 	 * d - Force bearer capability for ISDN/SS7 call to digital.
 	 */
 
@@ -13421,7 +13421,7 @@
 	if (toupper(args.group[0]) == 'G' || toupper(args.group[0])=='R') {
 		/* Retrieve the group number */
 		s = args.group + 1;
-		res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadance);
+		res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadence);
 		if (res < 1) {
 			ast_log(LOG_WARNING, "Unable to determine group for data %s\n", data);
 			return NULL;
@@ -13460,7 +13460,7 @@
 			x = CHAN_PSEUDO;
 			param->channelmatch = x;
 		} else {
-			res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadance);
+			res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadence);
 			if (res < 1) {
 				ast_log(LOG_WARNING, "Unable to determine channel for data %s\n", data);
 				return NULL;
@@ -13566,7 +13566,7 @@
 				break;
 			case 'r':
 				/* Distinctive ring */
-				p->distinctivering = start.cadance;
+				p->distinctivering = start.cadence;
 				break;
 			case 'd':
 #if defined(HAVE_PRI) || defined(HAVE_SS7)
@@ -13371,7 +13371,7 @@
 	 *
 	 * c - Wait for DTMF digit to confirm answer
-	 * r<cadance#> - Set distintive ring cadance number
+	 * r<cadence#> - Set distintive ring cadence number
 	 * d - Force bearer capability for ISDN/SS7 call to digital.
 	 */

-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/16785
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: Ie4740969444625e66f951c4622c842bbb95de2ec
Gerrit-Change-Number: 16785
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/4fcb770f/attachment-0001.html>


More information about the asterisk-code-review mailing list